unit optdata;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ComCtrls, StdCtrls, inifiles;

type
  TDataSourceInfo = Record
        Name:string;
        connstr:string;
  end;

  PDataSourceInfo = ^TDataSourceInfo;

  TDataSourceList = class
  private
    DataList:TList;
    IniFileName:string;

    function GetItems(ItemIndex: integer): TDataSourceInfo;
    procedure SetItems(ItemIndex: integer; const Value: TDataSourceInfo);
    function GetCount: integer;
  public
    property Items[ItemIndex:integer]:TDataSourceInfo read GetItems write SetItems;
    property Count:integer read GetCount;

    constructor Create;
    destructor Destroy; override;

    procedure Add(Value:TDataSourceInfo);
    procedure Delete(ItemIndex:integer);
    procedure Clear;
    procedure SaveToFile;
    procedure LoadfromFile;
    procedure SetFirst(index:integer);
  published

  end;


  { TDataSourceList }

implementation

{ TDataSourceList }

procedure TDataSourceList.Add(Value: TDataSourceInfo);
var
        PDsInfo:PDataSourceInfo;
begin
        new(PDsInfo);
        PDsInfo^ := Value;
        DataList.Add(PDsInfo);
end;

procedure TDataSourceList.Clear;
var
        i:integer;
begin
        for i := DataList.Count - 1 downto 0 do
        begin
                Delete(i);
        end;
end;

constructor TDataSourceList.Create;
begin
        IniFileName := GetCurrentDir + '\cfg.ini';
        DataList := TList.Create;
end;

procedure TDataSourceList.Delete(ItemIndex:integer);
var
        PDsInfo:PDataSourceInfo;
begin
        PDsInfo := DataList.Items[ItemIndex];
        Dispose(PDsInfo);
        DataList.Delete(ItemIndex);
end;

destructor TDataSourceList.Destroy;
begin
        Clear;       
        DataList.Free;
        inherited;

end;

function TDataSourceList.GetCount: integer;
begin
        Result := DataList.Count;
end;

function TDataSourceList.GetItems(ItemIndex: integer): TDataSourceInfo;
var
        PDsInfo:PDataSourceInfo;
begin
        PDsInfo := DataList.Items[ItemIndex];
        Result := PDsInfo^;
end;

procedure TDataSourceList.LoadfromFile;
var
        IniFile:TIniFile;
        i:integer;
        tmpslt:TStringList;
        DSValue:TDataSourceInfo;
begin
        tmpslt := TStringList.Create;
        IniFile := TIniFile.Create(IniFileName);
        IniFile.ReadSection('DataSource',tmpslt);
        for i := 0 to tmpslt.Count - 1 do
        begin
                DSValue.Name := tmpslt.Strings[i];
                DSValue.connstr := IniFile.ReadString('DataSource',DSValue.Name,'');
                Add(DSValue);                
        end;

        IniFile.free;
        tmpslt.Free;
        
end;

procedure TDataSourceList.SaveToFile;
var
        IniFile:TIniFile;
        i:integer;
begin
        IniFile := TIniFile.Create(IniFileName);
        IniFile.EraseSection('DataSource');
        for i := 0 to DataList.Count - 1 do
        begin
                IniFile.WriteString('DataSource',Items[i].Name,Items[i].connstr);
        end;


        IniFile.free;
end;

procedure TDataSourceList.SetItems(ItemIndex: integer;
  const Value: TDataSourceInfo);
var
        PDsInfo:PDataSourceInfo;
begin
        PDsInfo := DataList.Items[ItemIndex];
        PDsInfo^ := Value; 
end;

procedure TDataSourceList.SetFirst(index:integer);
begin
        DataList.Move(index,0);
end;

end.
